<a href='https://www.bsc.es/es'><img src='https://www.cmb.cat/wp-content/uploads/2014/01/BSC-Logo.jpg' align="right" height="100" width="100" /></a>

# Compound and cascading effects of climatic extremes on dengue outbreak risk in the Caribbean: an impact-based modelling framework with long-lag and short-lag interactions

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.15731719.svg)](https://doi.org/10.5281/zenodo.15731719)

<!-- badges: end -->

Data and R code to support Fletcher et al. (2025) Compound and cascading effects of climatic extremes on dengue outbreak risk in the Caribbean: an impact-based modelling framework with long-lag and short-lag interactions. *The Lancet Planetary Health*.

To cite this repository:

> *Fletcher C, Moirano G, Alcayna T, Rollock L, Van Meerbeeck CJ, Mahon R, Trotman A, Boodram LL, Browne T, Best S, Lührsen D, Díaz AR, Dunbar W, Lippi CA, Ryan SJ, Colón-González FJ, Stewart-Ibarra AM & Lowe R. (2025). Data and R-code to accompany 'Compound and cascading effects of climatic extremes on dengue outbreak risk in the Caribbean: an impact-based modelling framework with long-lag and short-lag interactions' (v1.0.0). Zenodo. https://doi.org/10.5281/zenodo.15731719*


## Structure
This repository contains processed data suitable for building the models described in the associated publication, along with the code used for data processing, analysis, and visualisation of the model outputs.

<pre>
<span style="color:#007acc;"><b>data</b></span>                                 Processed datasets for analysis, with associated metadata
<span style="color:#007acc;"><b>functions</b></span>                            Functions for conducting analysis and producing visualisations
<span style="color:#007acc;"><b>outputs</b></span>                              Outputs from modelling, cross validation and prediction
<span style="color:#007acc;"><b>supplementary</b></span>                        Scripts for supplementary materials and sensitivity analysis
<span style="color:#007acc;"><b>01_data_exploration.R</b></span>                Script for exploring and visualising data
<span style="color:#007acc;"><b>02_model_fitting.R</b></span>                   Script for fitting long-short-lag interaction models in INLA
<span style="color:#007acc;"><b>03_model_selection.R</b></span>                 Script for selecting candidate models
<span style="color:#007acc;"><b>04_cross_validation.R</b></span>                Script for performing rolling-origin cross validation
<span style="color:#007acc;"><b>05_combined_climate_contribution.R</b></span>   Script for quantifying combined contribution of climate covariates
<span style="color:#007acc;"><b>06_t20_cricket_forecast.R</b></span>            Script for generating dengue outbreak risk forecast for Twenty20 Cricket World Cup
</pre>


## Contributors
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/fletcher-chloe">Chloe Fletcher</a></strong>&nbsp;
  <a href="https://orcid.org/0000-0002-6705-7605">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/moirano-giovenale">Giovenale Moirano, PhD</a></strong>&nbsp;
  <a href="https://orcid.org/0000-0001-8748-3321">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/alcayna-tilly">Tilly Alcayna</a></strong>&nbsp;
  <a href="https://orcid.org/0000-0003-1237-1039">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Leslie Rollock</strong>,&nbsp;
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Cédric J Van Meerbeeck</strong>&nbsp;
  <a href="https://orcid.org/0000-0003-0833-0664">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Roché Mahon</strong>&nbsp;
  <a href="https://orcid.org/0000-0001-9621-7033">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Adrian Trotman</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-3099-8671">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Laura-Lee Boodram</strong>&nbsp;
  <a href="https://orcid.org/0000-0001-5535-3127">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Tia Browne</strong>,&nbsp;
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Sabu Best</strong>,&nbsp;
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/luhrsen-daniela-sofie">Daniela Lührsen</a></strong>&nbsp;
  <a href="https://orcid.org/0009-0002-6340-5964">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Avriel R Díaz</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-3108-7140">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Willy Dunbar</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-9134-9288">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Catherine A Lippi</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-7988-0324">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Sadie J Ryan</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-4308-6321">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Felipe J Colón-González</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-9671-3405">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong>Anna Stewart-Ibarra</strong>&nbsp;
  <a href="https://orcid.org/0000-0002-3383-4672">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>,
</span>
<span style="display: inline-block; margin-right: 15px;">
  <strong><a href="https://www.bsc.es/lowe-rachel">Professor Rachel Lowe</a></strong>&nbsp;
  <a href="https://orcid.org/0000-0003-3939-7343">
    <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="vertical-align: middle;" />
  </a>
</span>

</div>
